==> 1.0.1.tar.gz: lib/uibit.dart <==
library uibit;

import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
export 'package:flutter/material.dart';

export 'uibit/theme.dart';
export 'uibit/anim.dart';
export 'uibit/FadeInWidget.dart';
export 'uibit/ContainerClip.dart';
export 'uibit/BlurMask.dart';
export 'uibit/Button.dart';
export 'uibit/Toast.dart';
export 'uibit/FadePageRoute.dart';
export 'uibit/InkSwipe.dart';
export 'uibit/Room.dart';
export 'uibit/KSlider.dart';
export 'uibit/KText.dart';
export 'uibit/ResponsiveLayout.dart';
export 'uibit/HeadIndicator.dart';
export 'uibit/FabCircularMenu.dart';
export 'uibit/StarRating.dart';
export 'uibit/PopUp.dart';
export 'uibit/KTextField.dart';
export 'uibit/MContainer.dart';
export 'uibit/KTab.dart';
export 'uibit/XlivSwitcher.dart';
export 'uibit/ClipInnerRadius.dart';
export 'uibit/PathPrinter.dart';

typedef VCallback = void Function();
typedef VChanged<T> = void Function(T value);


class TController<Listener, Type> extends VController {
  List<Listener> _listenersT = [];

  notifyTListeners(Type type) {
    _listenersT.forEach((_listener) {
      (_listener as Function(Type type))(type);
    });
  }

  addTListener(Listener listener) => _listenersT.add(listener);

  removeTListener(Listener listener) => _listenersT.remove(listener);

  @override
  initState() {}

  @override
  dispose() {
    _listenersT = [];
  }
}

class VController implements IController {


  List<VCallback> _listeners = [];

  notifyListeners() {
    _listeners.forEach((_listener) {
      _listener();
    });
  }

  addListener(VCallback listener) => _listeners.add(listener);

  removeListener(VCallback listener) => _listeners.remove(listener);

  @override
  dispose() {
    _listeners.clear();
  }

  @override
  initState() {}
}

abstract class IController {
  initState();
  dispose();
}

abstract class TIInstance{
  init();
}


class PubSub<T> {
  VChanged<T> _puber;
  VChanged<T> _suber;

  void sub(T val) {
    if (_puber != null) _puber(val);
  }

  void pub(T val) {
    if (_suber != null) _suber(val);
  }

  void puber(dynamic puber) {
    _puber=puber;
  }

  void suber(dynamic suber) {
    _suber=suber;
  }

}


// ignore: non_constant_identifier_names
final Uikit = _Uikit();

class _Uikit {
  BuildContext context;

  MediaQueryData get mediaQuery => MediaQuery.of(context);

  init({BuildContext context}) {
    this.context = context;
  }
}

RenderParagraph getTextWidth(text, double width,{double fontSize = 14}) {
  RenderParagraph renderParagraph = RenderParagraph(TextSpan(text: text, style: TextStyle(fontSize: fontSize)), textDirection: TextDirection.ltr, maxLines: 1);
  renderParagraph.layout(BoxConstraints(maxWidth: width, minHeight: 0.0, minWidth: 0.0));
  return renderParagraph;
}

Size textSize(String text, TextStyle style) {
  final TextPainter textPainter = TextPainter(text: TextSpan(text: text, style: style), maxLines: 1, textDirection: TextDirection.ltr)..layout(minWidth: 0, maxWidth: double.infinity);
  return textPainter.size;
}

IconData getVolumeIcon(double backgroundVolume) {
  if (backgroundVolume >= 0.5) return Icons.volume_up;
  return backgroundVolume < 0.1 ? Icons.volume_off : Icons.volume_down;
}

==> 1.0.2.tar.gz: lib/uibit.dart <==
library uibit;

import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
export 'package:flutter/material.dart';

export 'uibit/theme.dart';
export 'uibit/anim.dart';
export 'uibit/FadeInWidget.dart';
export 'uibit/ContainerClip.dart';
export 'uibit/BlurMask.dart';
export 'uibit/Button.dart';
export 'uibit/Toast.dart';
export 'uibit/FadePageRoute.dart';
export 'uibit/InkSwipe.dart';
export 'uibit/Room.dart';
export 'uibit/KSlider.dart';
export 'uibit/KText.dart';
export 'uibit/ResponsiveLayout.dart';
export 'uibit/HeadIndicator.dart';
export 'uibit/FabCircularMenu.dart';
export 'uibit/StarRating.dart';
export 'uibit/PopUp.dart';
export 'uibit/KTextField.dart';
export 'uibit/MContainer.dart';
export 'uibit/KTab.dart';
export 'uibit/XlivSwitcher.dart';
export 'uibit/ClipInnerRadius.dart';
export 'uibit/PathPrinter.dart';

typedef VCallback = void Function();
typedef VChanged<T> = void Function(T value);


class TController<Listener, Type> extends VController {
  List<Listener> _listenersT = [];

  notifyTListeners(Type type) {
    _listenersT.forEach((_listener) {
      (_listener as Function(Type type))(type);
    });
  }

  addTListener(Listener listener) => _listenersT.add(listener);

  removeTListener(Listener listener) => _listenersT.remove(listener);

  @override
  initState() {}

  @override
  dispose() {
    _listenersT = [];
  }
}

class VController implements IController {


  List<VCallback> _listeners = [];

  notifyListeners() {
    _listeners.forEach((_listener) {
      _listener();
    });
  }

  addListener(VCallback listener) => _listeners.add(listener);

  removeListener(VCallback listener) => _listeners.remove(listener);

  @override
  dispose() {
    _listeners.clear();
  }

  @override
  initState() {}
}

abstract class IController {
  initState();
  dispose();
}

abstract class TIInstance{
  init();
}


class PubSub<T> {
  VChanged<T> _puber;
  VChanged<T> _suber;

  void sub(T val) {
    if (_puber != null) _puber(val);
  }

  void pub(T val) {
    if (_suber != null) _suber(val);
  }

  void puber(dynamic puber) {
    _puber=puber;
  }

  void suber(dynamic suber) {
    _suber=suber;
  }

}



class Uikit {
  static BuildContext context;

  static Color front=Color(0xFF8CC63F);
  static  Color mind = Color(0xFF447840);
  static  Color back = Color(0xFF002D40);

  static MediaQueryData get mediaQuery => MediaQuery.of(context);

  static initContext({BuildContext context}) {
    context = context;
  }
}

RenderParagraph getTextWidth(text, double width,{double fontSize = 14}) {
  RenderParagraph renderParagraph = RenderParagraph(TextSpan(text: text, style: TextStyle(fontSize: fontSize)), textDirection: TextDirection.ltr, maxLines: 1);
  renderParagraph.layout(BoxConstraints(maxWidth: width, minHeight: 0.0, minWidth: 0.0));
  return renderParagraph;
}

Size textSize(String text, TextStyle style) {
  final TextPainter textPainter = TextPainter(text: TextSpan(text: text, style: style), maxLines: 1, textDirection: TextDirection.ltr)..layout(minWidth: 0, maxWidth: double.infinity);
  return textPainter.size;
}

IconData getVolumeIcon(double backgroundVolume) {
  if (backgroundVolume >= 0.5) return Icons.volume_up;
  return backgroundVolume < 0.1 ? Icons.volume_off : Icons.volume_down;
}
